@@ -1,8 +1,8 @@
 module Mocha
-  
-  # Used as parameters for Expectation#with to restrict the parameter values which will match the expectation. Can be nested.
+
+  # Used as parameters for {Expectation#with} to restrict the parameter values which will match the expectation. Can be nested.
   module ParameterMatchers; end
-  
+
 end
 
 require 'mocha/parameter_matchers/object'
@@ -25,4 +25,4 @@ require 'mocha/parameter_matchers/optionally'
 require 'mocha/parameter_matchers/regexp_matches'
 require 'mocha/parameter_matchers/responds_with'
 require 'mocha/parameter_matchers/yaml_equivalent'
-require 'mocha/parameter_matchers/query_string'
+require 'mocha/parameter_matchers/equivalent_uri'
