@@ -148,7 +148,7 @@ class SequenceTest < Mocha::TestCase
       mock.first
     end
     assert_failed(test_result)
-    assert_match Regexp.new("in sequence 'one'"), test_result.failures.first.message
+    assert_match Regexp.new(%{in sequence "one"}), test_result.failures.first.message
   end
 
   def test_should_allow_expectations_to_be_in_more_than_one_sequence
@@ -166,8 +166,8 @@ class SequenceTest < Mocha::TestCase
       mock.second
     end
     assert_failed(test_result)
-    assert_match Regexp.new("in sequence 'one'"), test_result.failures.first.message
-    assert_match Regexp.new("in sequence 'two'"), test_result.failures.first.message
+    assert_match Regexp.new(%{in sequence "one"}), test_result.failures.first.message
+    assert_match Regexp.new(%{in sequence "two"}), test_result.failures.first.message
   end
 
   def test_should_have_shortcut_for_expectations_to_be_in_more_than_one_sequence
@@ -185,8 +185,8 @@ class SequenceTest < Mocha::TestCase
       mock.second
     end
     assert_failed(test_result)
-    assert_match Regexp.new("in sequence 'one'"), test_result.failures.first.message
-    assert_match Regexp.new("in sequence 'two'"), test_result.failures.first.message
+    assert_match Regexp.new(%{in sequence "one"}), test_result.failures.first.message
+    assert_match Regexp.new(%{in sequence "two"}), test_result.failures.first.message
   end
 
 end
