@@ -15,7 +15,10 @@ class StubbingOnNonMockObjectTest < Mocha::TestCase
 
   def test_should_allow_stubbing_method_on_non_mock_object
     Mocha::Configuration.allow(:stubbing_method_on_non_mock_object)
-    non_mock_object = Class.new { def existing_method; end }
+    non_mock_object = Class.new do
+      def existing_method
+      end
+    end
     test_result = run_as_test do
       non_mock_object.stubs(:existing_method)
     end
@@ -25,7 +28,10 @@ class StubbingOnNonMockObjectTest < Mocha::TestCase
 
   def test_should_warn_on_stubbing_method_on_non_mock_object
     Mocha::Configuration.warn_when(:stubbing_method_on_non_mock_object)
-    non_mock_object = Class.new { def existing_method; end }
+    non_mock_object = Class.new do
+      def existing_method
+      end
+    end
     test_result = run_as_test do
       non_mock_object.stubs(:existing_method)
     end
@@ -35,7 +41,10 @@ class StubbingOnNonMockObjectTest < Mocha::TestCase
 
   def test_should_prevent_stubbing_method_on_non_mock_object
     Mocha::Configuration.prevent(:stubbing_method_on_non_mock_object)
-    non_mock_object = Class.new { def existing_method; end }
+    non_mock_object = Class.new do
+      def existing_method
+      end
+    end
     test_result = run_as_test do
       non_mock_object.stubs(:existing_method)
     end
@@ -44,7 +53,10 @@ class StubbingOnNonMockObjectTest < Mocha::TestCase
   end
 
   def test_should_default_to_allow_stubbing_method_on_non_mock_object
-    non_mock_object = Class.new { def existing_method; end }
+    non_mock_object = Class.new do
+      def existing_method
+      end
+    end
     test_result = run_as_test do
       non_mock_object.stubs(:existing_method)
     end
