@@ -1,4 +1,5 @@
 require File.expand_path('../../test_helper', __FILE__)
+require 'mocha/ruby_version'
 require 'mocha/inspect'
 require 'method_definer'
 
@@ -25,7 +26,7 @@ class ObjectInspectTest < Mocha::TestCase
   def test_should_use_underscored_id_instead_of_object_id_or_id_so_that_they_can_be_stubbed
     calls = []
     object = Object.new
-    object.replace_instance_method(:id) { calls << :id; return 1 } if RUBY_VERSION < '1.9'
+    object.replace_instance_method(:id) { calls << :id; return 1 } if Mocha::PRE_RUBY_V19
     object.replace_instance_method(:object_id) { calls << :object_id; return 1 }
     object.replace_instance_method(:__id__) { calls << :__id__; return 1 }
     object.replace_instance_method(:inspect) { "object-description" }
