@@ -3,9 +3,9 @@ require 'mocha/inspect'
 
 class StringInspectTest < Mocha::TestCase
 
-  def test_should_replace_escaped_quotes_with_single_quote
+  def test_should_use_default_inspect_method
     string = "my_string"
-    assert_equal "'my_string'", string.mocha_inspect
+    assert_equal %{"my_string"}, string.mocha_inspect
   end
 
 end
